/*
 *     Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 *     Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 *     This library is free software; you can redistribute it and/or
 *     modify it under the terms of the GNU Lesser General Public
 *     License as published by the Free Software Foundation; version 2.1 of the License.
 *
 *     This library is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *     Lesser General Public License for more details.
 *
 *     You should have received a copy of the GNU Lesser General Public
 *     License along with this library; if not, write to the Free Software
 *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
plugins {
    `kotlin-dsl`
    `kotlin-dsl-precompiled-script-plugins`
    alias(libs.plugins.spotless)
}

dependencies {
    implementation(libs.build.androidLibrary)
    implementation(libs.build.spotless)
    implementation(libs.build.gitSemVer)
}

kotlin {
    compilerOptions {
        jvmToolchain(libs.versions.jvm.target.get().toInt())
    }
}

gradlePlugin {
    plugins {
        register("formatting-convention") {
            id = "temerity.formatting-convention"
            implementationClass = "edu.ucsc.its.temerity.buildlogic.convention.FormattingConventionPlugin"
        }
    }
    plugins {
        register("publication-convention") {
            id = "temerity.publication-convention"
            implementationClass = "edu.ucsc.its.temerity.buildlogic.convention.PublicationConventionPlugin"
        }
    }
    plugins {
        register("version-convention") {
            id = "temerity.version-convention"
            implementationClass = "edu.ucsc.its.temerity.buildlogic.convention.VersionConventionPlugin"
        }
    }
}

spotless {
    kotlin {
        target("**/*.kt")
        targetExclude("${project.layout.buildDirectory}/**/*.kt")
        ktlint().editorConfigOverride(
            mapOf(
                "indent_size" to "2",
                "continuation_indent_size" to "2",
            )
        )
        licenseHeaderFile(file("../spotless/LicenseHeader.kt"))
        trimTrailingWhitespace()
        endWithNewline()
    }
    format("kts") {
        target("**/*.kts")
        targetExclude("${project.layout.buildDirectory}/**/*.kts")
        licenseHeaderFile(file("../spotless/LicenseHeader.kt"), "(^(?![\\/ ]\\*).*$)")
        trimTrailingWhitespace()
        endWithNewline()
    }
}

// Excerpt from Project kt-fuzzy licensed under the MIT license
// By github.com/solo-studios, author solonovamax. See NOTICE file.
// Source: https://github.com/solo-studios/kt-fuzzy/blob/b3ae4f9f0e15ee38feb81b0edd88cdad68124b21/buildSrc/build.gradle.kts

fun gradlePlugin(id: Provider<PluginDependency>, version: Provider<String>): String {
    val pluginId = id.get().pluginId
    return "$pluginId:$pluginId.gradle.plugin:${version.get()}"
}
