/*
 *     Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 *     Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 *     This library is free software; you can redistribute it and/or
 *     modify it under the terms of the GNU Lesser General Public
 *     License as published by the Free Software Foundation; version 2.1 of the License.
 *
 *     This library is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *     Lesser General Public License for more details.
 *
 *     You should have received a copy of the GNU Lesser General Public
 *     License along with this library; if not, write to the Free Software
 *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package edu.ucsc.its.temerity.extensions.log

import co.touchlab.kermit.Message
import co.touchlab.kermit.MessageStringFormatter
import co.touchlab.kermit.Severity
import co.touchlab.kermit.Tag

internal abstract class WrappingFormatter(
  private val messageStringFormatter: MessageStringFormatter,
) : MessageStringFormatter {
  override fun formatMessage(severity: Severity?, tag: Tag?, message: Message): String {
    val prefix = prefix(severity, tag, message)
    val content = messageStringFormatter.formatMessage(severity, tag, message)
    val suffix = suffix(severity, tag, message)
    return "${prefix}$content$suffix"
  }

  open fun prefix(severity: Severity?, tag: Tag?, message: Message): String = ""
  open fun suffix(severity: Severity?, tag: Tag?, message: Message): String = ""
}
