/*
 *     Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 *     Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 *     This library is free software; you can redistribute it and/or
 *     modify it under the terms of the GNU Lesser General Public
 *     License as published by the Free Software Foundation; version 2.1 of the License.
 *
 *     This library is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *     Lesser General Public License for more details.
 *
 *     You should have received a copy of the GNU Lesser General Public
 *     License along with this library; if not, write to the Free Software
 *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package edu.ucsc.its.temerity.model

import kotlinx.serialization.SerialName
import kotlinx.serialization.Serializable

/*
 * Classes representing models used by the courses API
 * https://support.yuja.com/hc/en-us/articles/360049580714-YuJa-API#h_01H8YCQKJ2V48QFYQYKSHJJZYK
 */
@Serializable
public data class Course(
  @SerialName("embed_code")
  val embedCode: String = "",

  @SerialName("course_id")
  val courseId: Long = -1,

  @SerialName("publish_type")
  val publishType: String = "",

  @SerialName("is_active")
  val isActive: Boolean = false,

  @SerialName("course_code")
  val courseCode: String = "",

  @SerialName("course_name")
  val courseName: String = "",

  @SerialName("owner_id")
  val ownerId: Long = -1,

  @SerialName("sis_id")
  val sisId: String = "",

  @SerialName("course_security")
  val courseSecurity: String = "",

  @SerialName("course_term")
  val courseTerm: String = "",

  @SerialName("direct_link")
  val directLink: String = "",
)

@Serializable
public data class NewCourse(
  @SerialName("owner_id")
  val ownerId: Long = -1,

  @SerialName("course_name")
  val courseName: String = "",

  @SerialName("course_code")
  val courseCode: String = "",

  @SerialName("course_term")
  val courseTerm: String = "",

  @SerialName("publish_type")
  val publishType: String = "",
)
