/*
 *     Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 *     Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 *     This library is free software; you can redistribute it and/or
 *     modify it under the terms of the GNU Lesser General Public
 *     License as published by the Free Software Foundation; version 2.1 of the License.
 *
 *     This library is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *     Lesser General Public License for more details.
 *
 *     You should have received a copy of the GNU Lesser General Public
 *     License along with this library; if not, write to the Free Software
 *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
@file:Suppress("unused")

package edu.ucsc.its.temerity.extensions.log

import co.touchlab.kermit.DefaultFormatter
import co.touchlab.kermit.Message
import co.touchlab.kermit.MessageStringFormatter
import co.touchlab.kermit.Severity
import co.touchlab.kermit.Tag
import org.fusesource.jansi.Ansi

private fun withColor(messageStringFormatter: MessageStringFormatter = DefaultFormatter): MessageStringFormatter = ColorFormatter(messageStringFormatter)

private fun withBrightColor(messageStringFormatter: MessageStringFormatter = DefaultFormatter): MessageStringFormatter = BrightColorFormatter(messageStringFormatter)

internal class ColorFormatter(
  messageStringFormatter: MessageStringFormatter = DefaultFormatter,
) : WrappingFormatter(messageStringFormatter) {
  override fun prefix(severity: Severity?, tag: Tag?, message: Message) = severity?.toAnsiColor() ?: ""

  override fun suffix(severity: Severity?, tag: Tag?, message: Message) = resetColor()
}

internal class BrightColorFormatter(
  messageStringFormatter: MessageStringFormatter = DefaultFormatter,
) : WrappingFormatter(messageStringFormatter) {
  override fun prefix(severity: Severity?, tag: Tag?, message: Message) = severity?.toBrightAnsiColor() ?: ""

  override fun suffix(severity: Severity?, tag: Tag?, message: Message) = resetColor()
}

internal fun Severity.toBrightAnsiColor() = "${Ansi.ansi().fgBright(this.asColor())}"

internal fun Severity.toAnsiColor() = "${Ansi.ansi().fg(this.asColor())}"

internal fun resetColor() = "${Ansi.ansi().a(Ansi.Attribute.RESET)}"

internal fun Severity.asColor(): Ansi.Color = when (this) {
  Severity.Verbose -> Ansi.Color.WHITE
  Severity.Debug -> Ansi.Color.CYAN
  Severity.Info -> Ansi.Color.GREEN
  Severity.Warn -> Ansi.Color.YELLOW
  Severity.Error -> Ansi.Color.RED
  Severity.Assert -> Ansi.Color.MAGENTA
}
